@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.iap_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -183,9 +194,9 @@ class IdentityAwareProxyAdminServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, IdentityAwareProxyAdminServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the identity aware proxy admin service client.
@@ -229,10 +240,10 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def set_iam_policy(
         self,
-        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.SetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the access control policy for an Identity-Aware Proxy
@@ -242,6 +253,13 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -261,7 +279,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]):
+            request (Optional[Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]]):
                 The request object. Request message for `SetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -368,10 +386,10 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def get_iam_policy(
         self,
-        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.GetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the access control policy for an Identity-Aware Proxy
@@ -381,6 +399,13 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -400,7 +425,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]):
+            request (Optional[Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]]):
                 The request object. Request message for `GetIamPolicy`
                 method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -507,10 +532,10 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def test_iam_permissions(
         self,
-        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.TestIamPermissionsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Returns permissions that a caller has on the Identity-Aware
@@ -520,6 +545,13 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -530,7 +562,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 # Initialize request argument(s)
                 request = iam_policy_pb2.TestIamPermissionsRequest(
                     resource="resource_value",
-                    permissions=['permissions_value_1', 'permissions_value_2'],
+                    permissions=['permissions_value1', 'permissions_value2'],
                 )
 
                 # Make the request
@@ -540,7 +572,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]):
+            request (Optional[Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]]):
                 The request object. Request message for
                 `TestIamPermissions` method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -586,10 +618,10 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def get_iap_settings(
         self,
-        request: Union[service.GetIapSettingsRequest, dict] = None,
+        request: Optional[Union[service.GetIapSettingsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IapSettings:
         r"""Gets the IAP settings on a particular IAP protected
@@ -597,6 +629,13 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_get_iap_settings():
@@ -615,7 +654,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.GetIapSettingsRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.GetIapSettingsRequest, dict]]):
                 The request object. The request sent to GetIapSettings.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -657,10 +696,10 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def update_iap_settings(
         self,
-        request: Union[service.UpdateIapSettingsRequest, dict] = None,
+        request: Optional[Union[service.UpdateIapSettingsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IapSettings:
         r"""Updates the IAP settings on a particular IAP protected resource.
@@ -668,6 +707,13 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_update_iap_settings():
@@ -689,7 +735,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.UpdateIapSettingsRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.UpdateIapSettingsRequest, dict]]):
                 The request object. The request sent to
                 UpdateIapSettings.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -734,11 +780,11 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def list_tunnel_dest_groups(
         self,
-        request: Union[service.ListTunnelDestGroupsRequest, dict] = None,
+        request: Optional[Union[service.ListTunnelDestGroupsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTunnelDestGroupsAsyncPager:
         r"""Lists the existing TunnelDestGroups. To group across all
@@ -747,6 +793,13 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_list_tunnel_dest_groups():
@@ -766,7 +819,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.ListTunnelDestGroupsRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.ListTunnelDestGroupsRequest, dict]]):
                 The request object. The request to ListTunnelDestGroups.
             parent (:class:`str`):
                 Required. Google Cloud Project ID and location. In the
@@ -846,19 +899,26 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def create_tunnel_dest_group(
         self,
-        request: Union[service.CreateTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.CreateTunnelDestGroupRequest, dict]] = None,
         *,
-        parent: str = None,
-        tunnel_dest_group: service.TunnelDestGroup = None,
-        tunnel_dest_group_id: str = None,
+        parent: Optional[str] = None,
+        tunnel_dest_group: Optional[service.TunnelDestGroup] = None,
+        tunnel_dest_group_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.TunnelDestGroup:
         r"""Creates a new TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_create_tunnel_dest_group():
@@ -882,7 +942,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.CreateTunnelDestGroupRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.CreateTunnelDestGroupRequest, dict]]):
                 The request object. The request to
                 CreateTunnelDestGroup.
             parent (:class:`str`):
@@ -905,7 +965,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 becomes the final component of the resource name.
 
                 This value must be 4-63 characters, and valid characters
-                are ``[a-z][0-9]-``.
+                are ``[a-z]-``.
 
                 This corresponds to the ``tunnel_dest_group_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -968,17 +1028,24 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def get_tunnel_dest_group(
         self,
-        request: Union[service.GetTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.GetTunnelDestGroupRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.TunnelDestGroup:
         r"""Retrieves an existing TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_get_tunnel_dest_group():
@@ -997,7 +1064,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.GetTunnelDestGroupRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.GetTunnelDestGroupRequest, dict]]):
                 The request object. The request to GetTunnelDestGroup.
             name (:class:`str`):
                 Required. Name of the TunnelDestGroup to be fetched. In
@@ -1061,17 +1128,24 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def delete_tunnel_dest_group(
         self,
-        request: Union[service.DeleteTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.DeleteTunnelDestGroupRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_delete_tunnel_dest_group():
@@ -1087,7 +1161,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 await client.delete_tunnel_dest_group(request=request)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.DeleteTunnelDestGroupRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.DeleteTunnelDestGroupRequest, dict]]):
                 The request object. The request to
                 DeleteTunnelDestGroup.
             name (:class:`str`):
@@ -1145,18 +1219,25 @@ class IdentityAwareProxyAdminServiceAsyncClient:
 
     async def update_tunnel_dest_group(
         self,
-        request: Union[service.UpdateTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.UpdateTunnelDestGroupRequest, dict]] = None,
         *,
-        tunnel_dest_group: service.TunnelDestGroup = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        tunnel_dest_group: Optional[service.TunnelDestGroup] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.TunnelDestGroup:
         r"""Updates a TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_update_tunnel_dest_group():
@@ -1178,7 +1259,7 @@ class IdentityAwareProxyAdminServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.UpdateTunnelDestGroupRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.UpdateTunnelDestGroupRequest, dict]]):
                 The request object. The request to
                 UpdateTunnelDestGroup.
             tunnel_dest_group (:class:`google.cloud.iap_v1.types.TunnelDestGroup`):
@@ -1260,14 +1341,9 @@ class IdentityAwareProxyAdminServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-iap",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("IdentityAwareProxyAdminServiceAsyncClient",)
