@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.iap_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -67,7 +79,7 @@ class IdentityAwareProxyAdminServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[IdentityAwareProxyAdminServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -363,8 +375,8 @@ class IdentityAwareProxyAdminServiceClient(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, IdentityAwareProxyAdminServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, IdentityAwareProxyAdminServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the identity aware proxy admin service client.
@@ -378,7 +390,7 @@ class IdentityAwareProxyAdminServiceClient(
             transport (Union[str, IdentityAwareProxyAdminServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -408,6 +420,7 @@ class IdentityAwareProxyAdminServiceClient(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -460,10 +473,10 @@ class IdentityAwareProxyAdminServiceClient(
 
     def set_iam_policy(
         self,
-        request: Union[iam_policy_pb2.SetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.SetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Sets the access control policy for an Identity-Aware Proxy
@@ -473,6 +486,13 @@ class IdentityAwareProxyAdminServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -598,10 +618,10 @@ class IdentityAwareProxyAdminServiceClient(
 
     def get_iam_policy(
         self,
-        request: Union[iam_policy_pb2.GetIamPolicyRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.GetIamPolicyRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> policy_pb2.Policy:
         r"""Gets the access control policy for an Identity-Aware Proxy
@@ -611,6 +631,13 @@ class IdentityAwareProxyAdminServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -736,10 +763,10 @@ class IdentityAwareProxyAdminServiceClient(
 
     def test_iam_permissions(
         self,
-        request: Union[iam_policy_pb2.TestIamPermissionsRequest, dict] = None,
+        request: Optional[Union[iam_policy_pb2.TestIamPermissionsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Returns permissions that a caller has on the Identity-Aware
@@ -749,6 +776,13 @@ class IdentityAwareProxyAdminServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
             from google.iam.v1 import iam_policy_pb2  # type: ignore
 
@@ -759,7 +793,7 @@ class IdentityAwareProxyAdminServiceClient(
                 # Initialize request argument(s)
                 request = iam_policy_pb2.TestIamPermissionsRequest(
                     resource="resource_value",
-                    permissions=['permissions_value_1', 'permissions_value_2'],
+                    permissions=['permissions_value1', 'permissions_value2'],
                 )
 
                 # Make the request
@@ -814,10 +848,10 @@ class IdentityAwareProxyAdminServiceClient(
 
     def get_iap_settings(
         self,
-        request: Union[service.GetIapSettingsRequest, dict] = None,
+        request: Optional[Union[service.GetIapSettingsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IapSettings:
         r"""Gets the IAP settings on a particular IAP protected
@@ -825,6 +859,13 @@ class IdentityAwareProxyAdminServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_get_iap_settings():
@@ -886,10 +927,10 @@ class IdentityAwareProxyAdminServiceClient(
 
     def update_iap_settings(
         self,
-        request: Union[service.UpdateIapSettingsRequest, dict] = None,
+        request: Optional[Union[service.UpdateIapSettingsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IapSettings:
         r"""Updates the IAP settings on a particular IAP protected resource.
@@ -897,6 +938,13 @@ class IdentityAwareProxyAdminServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_update_iap_settings():
@@ -964,11 +1012,11 @@ class IdentityAwareProxyAdminServiceClient(
 
     def list_tunnel_dest_groups(
         self,
-        request: Union[service.ListTunnelDestGroupsRequest, dict] = None,
+        request: Optional[Union[service.ListTunnelDestGroupsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListTunnelDestGroupsPager:
         r"""Lists the existing TunnelDestGroups. To group across all
@@ -977,6 +1025,13 @@ class IdentityAwareProxyAdminServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_list_tunnel_dest_groups():
@@ -1076,19 +1131,26 @@ class IdentityAwareProxyAdminServiceClient(
 
     def create_tunnel_dest_group(
         self,
-        request: Union[service.CreateTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.CreateTunnelDestGroupRequest, dict]] = None,
         *,
-        parent: str = None,
-        tunnel_dest_group: service.TunnelDestGroup = None,
-        tunnel_dest_group_id: str = None,
+        parent: Optional[str] = None,
+        tunnel_dest_group: Optional[service.TunnelDestGroup] = None,
+        tunnel_dest_group_id: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.TunnelDestGroup:
         r"""Creates a new TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_create_tunnel_dest_group():
@@ -1135,7 +1197,7 @@ class IdentityAwareProxyAdminServiceClient(
                 becomes the final component of the resource name.
 
                 This value must be 4-63 characters, and valid characters
-                are ``[a-z][0-9]-``.
+                are ``[a-z]-``.
 
                 This corresponds to the ``tunnel_dest_group_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1198,17 +1260,24 @@ class IdentityAwareProxyAdminServiceClient(
 
     def get_tunnel_dest_group(
         self,
-        request: Union[service.GetTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.GetTunnelDestGroupRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.TunnelDestGroup:
         r"""Retrieves an existing TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_get_tunnel_dest_group():
@@ -1291,17 +1360,24 @@ class IdentityAwareProxyAdminServiceClient(
 
     def delete_tunnel_dest_group(
         self,
-        request: Union[service.DeleteTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.DeleteTunnelDestGroupRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_delete_tunnel_dest_group():
@@ -1375,18 +1451,25 @@ class IdentityAwareProxyAdminServiceClient(
 
     def update_tunnel_dest_group(
         self,
-        request: Union[service.UpdateTunnelDestGroupRequest, dict] = None,
+        request: Optional[Union[service.UpdateTunnelDestGroupRequest, dict]] = None,
         *,
-        tunnel_dest_group: service.TunnelDestGroup = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        tunnel_dest_group: Optional[service.TunnelDestGroup] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.TunnelDestGroup:
         r"""Updates a TunnelDestGroup.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_update_tunnel_dest_group():
@@ -1497,14 +1580,9 @@ class IdentityAwareProxyAdminServiceClient(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-iap",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("IdentityAwareProxyAdminServiceClient",)
