@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.iap_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -170,9 +181,9 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, IdentityAwareProxyOAuthServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the identity aware proxy o auth service client.
@@ -216,16 +227,23 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def list_brands(
         self,
-        request: Union[service.ListBrandsRequest, dict] = None,
+        request: Optional[Union[service.ListBrandsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.ListBrandsResponse:
         r"""Lists the existing brands for the project.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_list_brands():
@@ -244,7 +262,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.ListBrandsRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.ListBrandsRequest, dict]]):
                 The request object. The request sent to ListBrands.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -286,10 +304,10 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def create_brand(
         self,
-        request: Union[service.CreateBrandRequest, dict] = None,
+        request: Optional[Union[service.CreateBrandRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.Brand:
         r"""Constructs a new OAuth brand for the project if one
@@ -305,6 +323,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_create_brand():
@@ -323,7 +348,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.CreateBrandRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.CreateBrandRequest, dict]]):
                 The request object. The request sent to CreateBrand.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -368,16 +393,23 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def get_brand(
         self,
-        request: Union[service.GetBrandRequest, dict] = None,
+        request: Optional[Union[service.GetBrandRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.Brand:
         r"""Retrieves the OAuth brand of the project.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_get_brand():
@@ -396,7 +428,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.GetBrandRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.GetBrandRequest, dict]]):
                 The request object. The request sent to GetBrand.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -441,10 +473,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def create_identity_aware_proxy_client(
         self,
-        request: Union[service.CreateIdentityAwareProxyClientRequest, dict] = None,
+        request: Optional[
+            Union[service.CreateIdentityAwareProxyClientRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IdentityAwareProxyClient:
         r"""Creates an Identity Aware Proxy (IAP) OAuth client.
@@ -454,6 +488,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_create_identity_aware_proxy_client():
@@ -472,7 +513,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.CreateIdentityAwareProxyClientRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.CreateIdentityAwareProxyClientRequest, dict]]):
                 The request object. The request sent to
                 CreateIdentityAwareProxyClient.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -517,16 +558,25 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def list_identity_aware_proxy_clients(
         self,
-        request: Union[service.ListIdentityAwareProxyClientsRequest, dict] = None,
+        request: Optional[
+            Union[service.ListIdentityAwareProxyClientsRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListIdentityAwareProxyClientsAsyncPager:
         r"""Lists the existing clients for the brand.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_list_identity_aware_proxy_clients():
@@ -546,7 +596,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.ListIdentityAwareProxyClientsRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.ListIdentityAwareProxyClientsRequest, dict]]):
                 The request object. The request sent to
                 ListIdentityAwareProxyClients.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -603,10 +653,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def get_identity_aware_proxy_client(
         self,
-        request: Union[service.GetIdentityAwareProxyClientRequest, dict] = None,
+        request: Optional[
+            Union[service.GetIdentityAwareProxyClientRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IdentityAwareProxyClient:
         r"""Retrieves an Identity Aware Proxy (IAP) OAuth client.
@@ -614,6 +666,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_get_identity_aware_proxy_client():
@@ -632,7 +691,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.GetIdentityAwareProxyClientRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.GetIdentityAwareProxyClientRequest, dict]]):
                 The request object. The request sent to
                 GetIdentityAwareProxyClient.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -677,10 +736,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def reset_identity_aware_proxy_client_secret(
         self,
-        request: Union[service.ResetIdentityAwareProxyClientSecretRequest, dict] = None,
+        request: Optional[
+            Union[service.ResetIdentityAwareProxyClientSecretRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IdentityAwareProxyClient:
         r"""Resets an Identity Aware Proxy (IAP) OAuth client
@@ -689,6 +750,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_reset_identity_aware_proxy_client_secret():
@@ -707,7 +775,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.ResetIdentityAwareProxyClientSecretRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.ResetIdentityAwareProxyClientSecretRequest, dict]]):
                 The request object. The request sent to
                 ResetIdentityAwareProxyClientSecret.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -752,10 +820,12 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
     async def delete_identity_aware_proxy_client(
         self,
-        request: Union[service.DeleteIdentityAwareProxyClientRequest, dict] = None,
+        request: Optional[
+            Union[service.DeleteIdentityAwareProxyClientRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an Identity Aware Proxy (IAP) OAuth client.
@@ -765,6 +835,13 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             async def sample_delete_identity_aware_proxy_client():
@@ -780,7 +857,7 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
                 await client.delete_identity_aware_proxy_client(request=request)
 
         Args:
-            request (Union[google.cloud.iap_v1.types.DeleteIdentityAwareProxyClientRequest, dict]):
+            request (Optional[Union[google.cloud.iap_v1.types.DeleteIdentityAwareProxyClientRequest, dict]]):
                 The request object. The request sent to
                 DeleteIdentityAwareProxyClient.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -821,14 +898,9 @@ class IdentityAwareProxyOAuthServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-iap",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("IdentityAwareProxyOAuthServiceAsyncClient",)
