@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.iap_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -63,7 +75,7 @@ class IdentityAwareProxyOAuthServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[IdentityAwareProxyOAuthServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -321,8 +333,8 @@ class IdentityAwareProxyOAuthServiceClient(
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, IdentityAwareProxyOAuthServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, IdentityAwareProxyOAuthServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the identity aware proxy o auth service client.
@@ -336,7 +348,7 @@ class IdentityAwareProxyOAuthServiceClient(
             transport (Union[str, IdentityAwareProxyOAuthServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -366,6 +378,7 @@ class IdentityAwareProxyOAuthServiceClient(
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -418,16 +431,23 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def list_brands(
         self,
-        request: Union[service.ListBrandsRequest, dict] = None,
+        request: Optional[Union[service.ListBrandsRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.ListBrandsResponse:
         r"""Lists the existing brands for the project.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_list_brands():
@@ -489,10 +509,10 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def create_brand(
         self,
-        request: Union[service.CreateBrandRequest, dict] = None,
+        request: Optional[Union[service.CreateBrandRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.Brand:
         r"""Constructs a new OAuth brand for the project if one
@@ -508,6 +528,13 @@ class IdentityAwareProxyOAuthServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_create_brand():
@@ -572,16 +599,23 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def get_brand(
         self,
-        request: Union[service.GetBrandRequest, dict] = None,
+        request: Optional[Union[service.GetBrandRequest, dict]] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.Brand:
         r"""Retrieves the OAuth brand of the project.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_get_brand():
@@ -646,10 +680,12 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def create_identity_aware_proxy_client(
         self,
-        request: Union[service.CreateIdentityAwareProxyClientRequest, dict] = None,
+        request: Optional[
+            Union[service.CreateIdentityAwareProxyClientRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IdentityAwareProxyClient:
         r"""Creates an Identity Aware Proxy (IAP) OAuth client.
@@ -659,6 +695,13 @@ class IdentityAwareProxyOAuthServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_create_identity_aware_proxy_client():
@@ -725,16 +768,25 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def list_identity_aware_proxy_clients(
         self,
-        request: Union[service.ListIdentityAwareProxyClientsRequest, dict] = None,
+        request: Optional[
+            Union[service.ListIdentityAwareProxyClientsRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListIdentityAwareProxyClientsPager:
         r"""Lists the existing clients for the brand.
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_list_identity_aware_proxy_clients():
@@ -814,10 +866,12 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def get_identity_aware_proxy_client(
         self,
-        request: Union[service.GetIdentityAwareProxyClientRequest, dict] = None,
+        request: Optional[
+            Union[service.GetIdentityAwareProxyClientRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IdentityAwareProxyClient:
         r"""Retrieves an Identity Aware Proxy (IAP) OAuth client.
@@ -825,6 +879,13 @@ class IdentityAwareProxyOAuthServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_get_identity_aware_proxy_client():
@@ -891,10 +952,12 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def reset_identity_aware_proxy_client_secret(
         self,
-        request: Union[service.ResetIdentityAwareProxyClientSecretRequest, dict] = None,
+        request: Optional[
+            Union[service.ResetIdentityAwareProxyClientSecretRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> service.IdentityAwareProxyClient:
         r"""Resets an Identity Aware Proxy (IAP) OAuth client
@@ -903,6 +966,13 @@ class IdentityAwareProxyOAuthServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_reset_identity_aware_proxy_client_secret():
@@ -969,10 +1039,12 @@ class IdentityAwareProxyOAuthServiceClient(
 
     def delete_identity_aware_proxy_client(
         self,
-        request: Union[service.DeleteIdentityAwareProxyClientRequest, dict] = None,
+        request: Optional[
+            Union[service.DeleteIdentityAwareProxyClientRequest, dict]
+        ] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes an Identity Aware Proxy (IAP) OAuth client.
@@ -982,6 +1054,13 @@ class IdentityAwareProxyOAuthServiceClient(
 
         .. code-block:: python
 
+            # This snippet has been automatically generated and should be regarded as a
+            # code template only.
+            # It will require modifications to work:
+            # - It may require correct/in-range values for request initialization.
+            # - It may require specifying regional endpoints when creating the service
+            #   client as shown in:
+            #   https://googleapis.dev/python/google-api-core/latest/client_options.html
             from google.cloud import iap_v1
 
             def sample_delete_identity_aware_proxy_client():
@@ -1048,14 +1127,9 @@ class IdentityAwareProxyOAuthServiceClient(
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-iap",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("IdentityAwareProxyOAuthServiceClient",)
