@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
@@ -36,9 +38,11 @@ __protobuf__ = proto.module(
         "CorsSettings",
         "OAuthSettings",
         "ReauthSettings",
+        "AllowedDomainsSettings",
         "ApplicationSettings",
         "CsmSettings",
         "AccessDeniedPageSettings",
+        "AttributePropagationSettings",
         "ListBrandsRequest",
         "ListBrandsResponse",
         "CreateBrandRequest",
@@ -81,15 +85,15 @@ class ListTunnelDestGroupsRequest(proto.Message):
             the page token.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -99,7 +103,7 @@ class ListTunnelDestGroupsResponse(proto.Message):
     r"""The response from ListTunnelDestGroups.
 
     Attributes:
-        tunnel_dest_groups (Sequence[google.cloud.iap_v1.types.TunnelDestGroup]):
+        tunnel_dest_groups (MutableSequence[google.cloud.iap_v1.types.TunnelDestGroup]):
             TunnelDestGroup existing in the project.
         next_page_token (str):
             A token that you can send as ``page_token`` to retrieve the
@@ -111,12 +115,12 @@ class ListTunnelDestGroupsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    tunnel_dest_groups = proto.RepeatedField(
+    tunnel_dest_groups: MutableSequence["TunnelDestGroup"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="TunnelDestGroup",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -137,19 +141,19 @@ class CreateTunnelDestGroupRequest(proto.Message):
             becomes the final component of the resource name.
 
             This value must be 4-63 characters, and valid characters are
-            ``[a-z][0-9]-``.
+            ``[a-z]-``.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    tunnel_dest_group = proto.Field(
+    tunnel_dest_group: "TunnelDestGroup" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="TunnelDestGroup",
     )
-    tunnel_dest_group_id = proto.Field(
+    tunnel_dest_group_id: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -165,7 +169,7 @@ class GetTunnelDestGroupRequest(proto.Message):
             ``projects/{project_number/id}/iap_tunnel/locations/{location}/destGroups/{dest_group}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -181,7 +185,7 @@ class DeleteTunnelDestGroupRequest(proto.Message):
             ``projects/{project_number/id}/iap_tunnel/locations/{location}/destGroups/{dest_group}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -201,12 +205,12 @@ class UpdateTunnelDestGroupRequest(proto.Message):
             https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
     """
 
-    tunnel_dest_group = proto.Field(
+    tunnel_dest_group: "TunnelDestGroup" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="TunnelDestGroup",
     )
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=2,
         message=field_mask_pb2.FieldMask,
@@ -220,24 +224,25 @@ class TunnelDestGroup(proto.Message):
         name (str):
             Required. Immutable. Identifier for the
             TunnelDestGroup. Must be unique within the
-            project.
-        cidrs (Sequence[str]):
-            null List of CIDRs that this group applies
-            to.
-        fqdns (Sequence[str]):
-            null List of FQDNs that this group applies
-            to.
+            project and contain only lower case letters
+            (a-z) and dashes (-).
+        cidrs (MutableSequence[str]):
+            Unordered list. List of CIDRs that this group
+            applies to.
+        fqdns (MutableSequence[str]):
+            Unordered list. List of FQDNs that this group
+            applies to.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    cidrs = proto.RepeatedField(
+    cidrs: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=2,
     )
-    fqdns = proto.RepeatedField(
+    fqdns: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=3,
     )
@@ -253,7 +258,7 @@ class GetIapSettingsRequest(proto.Message):
             permission for the associated resource.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -274,12 +279,12 @@ class UpdateIapSettingsRequest(proto.Message):
             https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
     """
 
-    iap_settings = proto.Field(
+    iap_settings: "IapSettings" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="IapSettings",
     )
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=2,
         message=field_mask_pb2.FieldMask,
@@ -301,16 +306,16 @@ class IapSettings(proto.Message):
             settings in IAP
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    access_settings = proto.Field(
+    access_settings: "AccessSettings" = proto.Field(
         proto.MESSAGE,
         number=5,
         message="AccessSettings",
     )
-    application_settings = proto.Field(
+    application_settings: "ApplicationSettings" = proto.Field(
         proto.MESSAGE,
         number=6,
         message="ApplicationSettings",
@@ -332,35 +337,43 @@ class AccessSettings(proto.Message):
         reauth_settings (google.cloud.iap_v1.types.ReauthSettings):
             Settings to configure reauthentication
             policies in IAP.
+        allowed_domains_settings (google.cloud.iap_v1.types.AllowedDomainsSettings):
+            Settings to configure and enable allowed
+            domains.
     """
 
-    gcip_settings = proto.Field(
+    gcip_settings: "GcipSettings" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="GcipSettings",
     )
-    cors_settings = proto.Field(
+    cors_settings: "CorsSettings" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="CorsSettings",
     )
-    oauth_settings = proto.Field(
+    oauth_settings: "OAuthSettings" = proto.Field(
         proto.MESSAGE,
         number=3,
         message="OAuthSettings",
     )
-    reauth_settings = proto.Field(
+    reauth_settings: "ReauthSettings" = proto.Field(
         proto.MESSAGE,
         number=6,
         message="ReauthSettings",
     )
+    allowed_domains_settings: "AllowedDomainsSettings" = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="AllowedDomainsSettings",
+    )
 
 
 class GcipSettings(proto.Message):
     r"""Allows customers to configure tenant_id for GCIP instance per-app.
 
     Attributes:
-        tenant_ids (Sequence[str]):
+        tenant_ids (MutableSequence[str]):
             GCIP tenant ids that are linked to the IAP resource.
             tenant_ids could be a string beginning with a number
             character to indicate authenticating with GCIP tenant flow,
@@ -376,11 +389,11 @@ class GcipSettings(proto.Message):
             level.
     """
 
-    tenant_ids = proto.RepeatedField(
+    tenant_ids: MutableSequence[str] = proto.RepeatedField(
         proto.STRING,
         number=1,
     )
-    login_page_uri = proto.Field(
+    login_page_uri: wrappers_pb2.StringValue = proto.Field(
         proto.MESSAGE,
         number=2,
         message=wrappers_pb2.StringValue,
@@ -399,7 +412,7 @@ class CorsSettings(proto.Message):
             apply any special logic to OPTIONS requests.
     """
 
-    allow_http_options = proto.Field(
+    allow_http_options: wrappers_pb2.BoolValue = proto.Field(
         proto.MESSAGE,
         number=1,
         message=wrappers_pb2.BoolValue,
@@ -421,7 +434,7 @@ class OAuthSettings(proto.Message):
             is managed by IAM policies.
     """
 
-    login_hint = proto.Field(
+    login_hint: wrappers_pb2.StringValue = proto.Field(
         proto.MESSAGE,
         number=2,
         message=wrappers_pb2.StringValue,
@@ -433,7 +446,7 @@ class ReauthSettings(proto.Message):
 
     Attributes:
         method (google.cloud.iap_v1.types.ReauthSettings.Method):
-            Reauth method required by the policy.
+            Reauth method requested.
         max_age (google.protobuf.duration_pb2.Duration):
             Reauth session lifetime, how long before a
             user has to reauthenticate again.
@@ -457,61 +470,97 @@ class ReauthSettings(proto.Message):
         MINIMUM = 1
         DEFAULT = 2
 
-    method = proto.Field(
+    method: Method = proto.Field(
         proto.ENUM,
         number=1,
         enum=Method,
     )
-    max_age = proto.Field(
+    max_age: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=2,
         message=duration_pb2.Duration,
     )
-    policy_type = proto.Field(
+    policy_type: PolicyType = proto.Field(
         proto.ENUM,
         number=3,
         enum=PolicyType,
     )
 
 
+class AllowedDomainsSettings(proto.Message):
+    r"""Configuration for IAP allowed domains. Lets you to restrict
+    access to an app and allow access to only the domains that you
+    list.
+
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        enable (bool):
+            Configuration for customers to opt in for the
+            feature.
+
+            This field is a member of `oneof`_ ``_enable``.
+        domains (MutableSequence[str]):
+            List of trusted domains.
+    """
+
+    enable: bool = proto.Field(
+        proto.BOOL,
+        number=1,
+        optional=True,
+    )
+    domains: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+
+
 class ApplicationSettings(proto.Message):
     r"""Wrapper over application specific settings for IAP.
 
     Attributes:
         csm_settings (google.cloud.iap_v1.types.CsmSettings):
             Settings to configure IAP's behavior for a
-            CSM mesh.
+            service mesh.
         access_denied_page_settings (google.cloud.iap_v1.types.AccessDeniedPageSettings):
             Customization for Access Denied page.
         cookie_domain (google.protobuf.wrappers_pb2.StringValue):
             The Domain value to set for cookies generated
             by IAP. This value is not validated by the API,
             but will be ignored at runtime if invalid.
+        attribute_propagation_settings (google.cloud.iap_v1.types.AttributePropagationSettings):
+            Settings to configure attribute propagation.
     """
 
-    csm_settings = proto.Field(
+    csm_settings: "CsmSettings" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="CsmSettings",
     )
-    access_denied_page_settings = proto.Field(
+    access_denied_page_settings: "AccessDeniedPageSettings" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="AccessDeniedPageSettings",
     )
-    cookie_domain = proto.Field(
+    cookie_domain: wrappers_pb2.StringValue = proto.Field(
         proto.MESSAGE,
         number=3,
         message=wrappers_pb2.StringValue,
     )
+    attribute_propagation_settings: "AttributePropagationSettings" = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="AttributePropagationSettings",
+    )
 
 
 class CsmSettings(proto.Message):
-    r"""Configuration for RCTokens generated for CSM workloads
-    protected by IAP. RCTokens are IAP generated JWTs that can be
-    verified at the application. The RCToken is primarily used for
-    ISTIO deployments, and can be scoped to a single mesh by
-    configuring the audience field accordingly
+    r"""Configuration for RCToken generated for service mesh
+    workloads protected by IAP. RCToken are IAP generated JWTs that
+    can be verified at the application. The RCToken is primarily
+    used for service mesh deployments, and can be scoped to a single
+    mesh by configuring the audience field accordingly.
 
     Attributes:
         rctoken_aud (google.protobuf.wrappers_pb2.StringValue):
@@ -519,7 +568,7 @@ class CsmSettings(proto.Message):
             This value is not validated by IAP.
     """
 
-    rctoken_aud = proto.Field(
+    rctoken_aud: wrappers_pb2.StringValue = proto.Field(
         proto.MESSAGE,
         number=1,
         message=wrappers_pb2.StringValue,
@@ -532,6 +581,9 @@ class AccessDeniedPageSettings(proto.Message):
     page when access is denied to users. If IAP prevents access to
     this page, the default IAP error page will be displayed instead.
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         access_denied_page_uri (google.protobuf.wrappers_pb2.StringValue):
             The URI to be redirected to when access is
@@ -539,18 +591,112 @@ class AccessDeniedPageSettings(proto.Message):
         generate_troubleshooting_uri (google.protobuf.wrappers_pb2.BoolValue):
             Whether to generate a troubleshooting URL on
             access denied events to this application.
+        remediation_token_generation_enabled (google.protobuf.wrappers_pb2.BoolValue):
+            Whether to generate remediation token on
+            access denied events to this application.
+
+            This field is a member of `oneof`_ ``_remediation_token_generation_enabled``.
     """
 
-    access_denied_page_uri = proto.Field(
+    access_denied_page_uri: wrappers_pb2.StringValue = proto.Field(
         proto.MESSAGE,
         number=1,
         message=wrappers_pb2.StringValue,
     )
-    generate_troubleshooting_uri = proto.Field(
+    generate_troubleshooting_uri: wrappers_pb2.BoolValue = proto.Field(
         proto.MESSAGE,
         number=2,
         message=wrappers_pb2.BoolValue,
     )
+    remediation_token_generation_enabled: wrappers_pb2.BoolValue = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        optional=True,
+        message=wrappers_pb2.BoolValue,
+    )
+
+
+class AttributePropagationSettings(proto.Message):
+    r"""Configuration for propagating attributes to applications
+    protected by IAP.
+
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
+    Attributes:
+        expression (str):
+            Raw string CEL expression. Must return a list of attributes.
+            Maximum of 45 attributes can be selected. Expressions can
+            select different attribute types from ``attributes``:
+            ``attributes.saml_attributes``,
+            ``attributes.iap_attributes``. Limited functions are
+            supported:
+
+            -  ``filter: <list>.filter(<iter_var>, <predicate>)`` ->
+               returns a subset of ``<list>`` where ``<predicate>`` is
+               true for every item.
+            -  ``in: <var> in <list>`` -> returns true if ``<list>``
+               contains ``<var>``
+            -  ``selectByName: <list>.selectByName(<string>)`` ->
+               returns the attribute in ``<list>`` with the given
+               ``<string>`` name, otherwise returns empty.
+            -  ``emitAs: <attribute>.emitAs(<string>)`` -> sets the
+               ``<attribute>`` name field to the given ``<string>`` for
+               propagation in selected output credentials.
+            -  ``strict: <attribute>.strict()`` -> ignore the
+               ``x-goog-iap-attr-`` prefix for the provided
+               ``<attribute>`` when propagating via the ``HEADER``
+               output credential, i.e. request headers.
+            -  ``append: <target_list>.append(<attribute>)`` OR
+               ``<target_list>.append(<list>)`` -> append the provided
+               ``<attribute>`` or ``<list>`` onto the end of
+               ``<target_list>``.
+
+            Example expression:
+            ``attributes.saml_attributes.filter(x, x.name in ['test']).append(attributes.iap_attributes.selectByName('exact').emitAs('custom').strict())``
+
+            This field is a member of `oneof`_ ``_expression``.
+        output_credentials (MutableSequence[google.cloud.iap_v1.types.AttributePropagationSettings.OutputCredentials]):
+            Which output credentials attributes selected
+            by the CEL expression should be propagated in.
+            All attributes will be fully duplicated in each
+            selected output credential.
+        enable (bool):
+            Whether the provided attribute propagation
+            settings should be evaluated on user requests.
+            If set to true, attributes returned from the
+            expression will be propagated in the set output
+            credentials.
+
+            This field is a member of `oneof`_ ``_enable``.
+    """
+
+    class OutputCredentials(proto.Enum):
+        r"""Supported output credentials for attribute propagation. Each
+        output credential maps to a "field" in the response. For
+        example, selecting JWT will propagate all attributes in the IAP
+        JWT, header in the headers, etc.
+        """
+        OUTPUT_CREDENTIALS_UNSPECIFIED = 0
+        HEADER = 1
+        JWT = 2
+        RCTOKEN = 3
+
+    expression: str = proto.Field(
+        proto.STRING,
+        number=1,
+        optional=True,
+    )
+    output_credentials: MutableSequence[OutputCredentials] = proto.RepeatedField(
+        proto.ENUM,
+        number=2,
+        enum=OutputCredentials,
+    )
+    enable: bool = proto.Field(
+        proto.BOOL,
+        number=3,
+        optional=True,
+    )
 
 
 class ListBrandsRequest(proto.Message):
@@ -562,7 +708,7 @@ class ListBrandsRequest(proto.Message):
             projects/{project_number/id}.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -572,11 +718,11 @@ class ListBrandsResponse(proto.Message):
     r"""Response message for ListBrands.
 
     Attributes:
-        brands (Sequence[google.cloud.iap_v1.types.Brand]):
+        brands (MutableSequence[google.cloud.iap_v1.types.Brand]):
             Brands existing in the project.
     """
 
-    brands = proto.RepeatedField(
+    brands: MutableSequence["Brand"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Brand",
@@ -595,11 +741,11 @@ class CreateBrandRequest(proto.Message):
             Required. The brand to be created.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    brand = proto.Field(
+    brand: "Brand" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="Brand",
@@ -615,7 +761,7 @@ class GetBrandRequest(proto.Message):
             format: projects/{project_number/id}/brands/{brand}.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -644,15 +790,15 @@ class ListIdentityAwareProxyClientsRequest(proto.Message):
             provided the page token.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -662,7 +808,7 @@ class ListIdentityAwareProxyClientsResponse(proto.Message):
     r"""Response message for ListIdentityAwareProxyClients.
 
     Attributes:
-        identity_aware_proxy_clients (Sequence[google.cloud.iap_v1.types.IdentityAwareProxyClient]):
+        identity_aware_proxy_clients (MutableSequence[google.cloud.iap_v1.types.IdentityAwareProxyClient]):
             Clients existing in the brand.
         next_page_token (str):
             A token, which can be send as ``page_token`` to retrieve the
@@ -674,12 +820,14 @@ class ListIdentityAwareProxyClientsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    identity_aware_proxy_clients = proto.RepeatedField(
+    identity_aware_proxy_clients: MutableSequence[
+        "IdentityAwareProxyClient"
+    ] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="IdentityAwareProxyClient",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -698,11 +846,11 @@ class CreateIdentityAwareProxyClientRequest(proto.Message):
             created.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    identity_aware_proxy_client = proto.Field(
+    identity_aware_proxy_client: "IdentityAwareProxyClient" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="IdentityAwareProxyClient",
@@ -719,7 +867,7 @@ class GetIdentityAwareProxyClientRequest(proto.Message):
             projects/{project_number/id}/brands/{brand}/identityAwareProxyClients/{client_id}.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -735,7 +883,7 @@ class ResetIdentityAwareProxyClientSecretRequest(proto.Message):
             projects/{project_number/id}/brands/{brand}/identityAwareProxyClients/{client_id}.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -751,7 +899,7 @@ class DeleteIdentityAwareProxyClientRequest(proto.Message):
             projects/{project_number/id}/brands/{brand}/identityAwareProxyClients/{client_id}.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -780,19 +928,19 @@ class Brand(proto.Message):
             organization only.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    support_email = proto.Field(
+    support_email: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    application_title = proto.Field(
+    application_title: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    org_internal_only = proto.Field(
+    org_internal_only: bool = proto.Field(
         proto.BOOL,
         number=4,
     )
@@ -814,15 +962,15 @@ class IdentityAwareProxyClient(proto.Message):
             client.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    secret = proto.Field(
+    secret: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=3,
     )
